@@ -21,10 +21,10 @@
  *
  */
 
-/* @file hildon-file-details-dialog.c
- *
+/* @file hildon-file-details-dialog.c 
+ * 
  * This file contains API for Hildon File Details dialog.
- *
+ * 
  */
 
 #include <gtk/gtkcheckbutton.h>
@@ -38,10 +38,9 @@
 #include <libintl.h>
 #include <libgnomevfs/gnome-vfs.h>
 
-#include <hildon/hildon-banner.h>
-#include <hildon/hildon-caption.h>
-#include <hildon/hildon-defines.h>
-
+#include <hildon-widgets/hildon-caption.h>
+#include <hildon-widgets/gtk-infoprint.h>
+#include <hildon-widgets/hildon-defines.h>
 #include "hildon-file-details-dialog.h"
 #include "hildon-file-system-model.h"
 
@@ -89,12 +88,12 @@ static void hildon_file_details_dialog_finalize(GObject * object);
 
 static void
 hildon_file_details_dialog_set_property( GObject *object, guint param_id,
-                                                           const GValue *value,
+			                                   const GValue *value,
                                          GParamSpec *pspec );
 static void
 hildon_file_details_dialog_get_property( GObject *object, guint param_id,
-                                                           GValue *value, GParamSpec *pspec );
-static void
+			                                   GValue *value, GParamSpec *pspec );
+static void 
 hildon_file_details_dialog_response(GtkDialog *dialog, gint response_id);
 
 static GtkDialogClass *file_details_dialog_parent_class = NULL;
@@ -133,11 +132,11 @@ static gboolean write_access(const gchar *uri)
 
   /* Get information about file */
   info = gnome_vfs_file_info_new ();
-  if (gnome_vfs_get_file_info(uri, info,
+  if (gnome_vfs_get_file_info(uri, info, 
     GNOME_VFS_FILE_INFO_GET_ACCESS_RIGHTS) == GNOME_VFS_OK)
 
     /* Detect that the file is writable or not */
-    result = ((info->permissions & GNOME_VFS_PERM_ACCESS_WRITABLE)
+    result = ((info->permissions & GNOME_VFS_PERM_ACCESS_WRITABLE) 
               == GNOME_VFS_PERM_ACCESS_WRITABLE);
 
   gnome_vfs_file_info_unref(info);
@@ -146,7 +145,7 @@ static gboolean write_access(const gchar *uri)
 
 /* When model deletes a file, we check if our reference is still valid.
    If not, we emit response, which usually closes the dialog */
-static void check_validity(GtkTreeModel *model,
+static void check_validity(GtkTreeModel *model, 
   GtkTreePath *path, gpointer data)
 {
   GtkTreeRowReference *ref;
@@ -165,20 +164,20 @@ static void change_state(HildonFileDetailsDialog *self, gboolean readonly)
 
   g_return_if_fail(HILDON_IS_FILE_DETAILS_DIALOG(self));
 
-  /* We fail to get the iterator in cases when the reference is
+  /* We fail to get the iterator in cases when the reference is 
      invalidated, for example when the file is removed. */
   if (hildon_file_details_dialog_get_file_iter(self, &iter))
-  {
+  {  
     gchar *uri;
     GnomeVFSFileInfo *info;
     GnomeVFSResult result;
 
     /* Get the value of cells referenced by a tree_modle */
-    gtk_tree_model_get(GTK_TREE_MODEL(self->priv->model), &iter,
-      HILDON_FILE_SYSTEM_MODEL_COLUMN_URI, &uri, -1);
+    gtk_tree_model_get(GTK_TREE_MODEL(self->priv->model), &iter, 
+      HILDON_FILE_SYSTEM_MODEL_COLUMN_URI, &uri, -1);    
 
     info = gnome_vfs_file_info_new();
-    result = gnome_vfs_get_file_info(uri, info,
+    result = gnome_vfs_get_file_info(uri, info, 
       GNOME_VFS_FILE_INFO_DEFAULT);
 
     /* Change the file information */
@@ -186,24 +185,23 @@ static void change_state(HildonFileDetailsDialog *self, gboolean readonly)
     {
       if (readonly)
         info->permissions &= ~(S_IWUSR | S_IWGRP | S_IWOTH);
-      else
+      else      
         info->permissions |= (S_IWUSR | S_IWGRP);
-
-      result = gnome_vfs_set_file_info(uri, info,
+      
+      result = gnome_vfs_set_file_info(uri, info, 
           GNOME_VFS_SET_FILE_INFO_PERMISSIONS);
     }
 
     if (result != GNOME_VFS_OK)
-      hildon_banner_show_information (GTK_WIDGET (self), NULL,
-                                      gnome_vfs_result_to_string (result));
-
+      gtk_infoprint(GTK_WINDOW(self), gnome_vfs_result_to_string(result));
+    
     gnome_vfs_file_info_unref(info);
     g_free(uri);
   }
 }
 
 /* Cancel changes if read-only is changed */
-static void
+static void 
 hildon_file_details_dialog_response(GtkDialog *dialog, gint response_id)
 {
     if (response_id == GTK_RESPONSE_CANCEL)
@@ -211,7 +209,7 @@ hildon_file_details_dialog_response(GtkDialog *dialog, gint response_id)
       HildonFileDetailsDialog *self;
       gboolean state;
 
-      self = HILDON_FILE_DETAILS_DIALOG(dialog);
+      self = HILDON_FILE_DETAILS_DIALOG(dialog);  
       state = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(self->priv->file_readonly));
 
       if (state != self->priv->checkbox_original_state)
@@ -222,22 +220,22 @@ hildon_file_details_dialog_response(GtkDialog *dialog, gint response_id)
 static void
 hildon_file_details_dialog_read_only_toggled(GtkWidget *widget, gpointer data)
 {
-  change_state(HILDON_FILE_DETAILS_DIALOG(data),
+  change_state(HILDON_FILE_DETAILS_DIALOG(data), 
     gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget)));
 }
 
-static void
+static void 
 hildon_file_details_dialog_map(GtkWidget *widget)
 {
   HildonFileDetailsDialogPrivate *priv;
 
   priv = HILDON_FILE_DETAILS_DIALOG(widget)->priv;
 
-  /* Map the GtkWidget */
+  /* Map the GtkWidget */ 
   GTK_WIDGET_CLASS(file_details_dialog_parent_class)->map(widget);
 
   /* Set the first page as default and
-   * make the GtkNotebook focusable if it shows tabs */
+   * make the GtkNotebook focusable if it shows tabs */ 
   if (gtk_notebook_get_show_tabs(priv->notebook))
   {
     gtk_notebook_set_current_page(priv->notebook, 0);
@@ -274,7 +272,7 @@ hildon_file_details_dialog_class_init(HildonFileDetailsDialogClass * klass)
                                    g_param_spec_object("additional-tab",
                                    "Additional tab",
                                    "Tab to show additinal information",
-                                   GTK_TYPE_WIDGET,
+			           GTK_TYPE_WIDGET,
                                    G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
   /**
    * HildonFileDetailsDialog:show_tabs:
@@ -289,7 +287,7 @@ hildon_file_details_dialog_class_init(HildonFileDetailsDialogClass * klass)
   /**
    * HildonFileDetailsDialog:additional_tab_label:
    *
-   *
+   * 
    */
   g_object_class_install_property( gobject_class, PROP_ADDITIONAL_TAB_LABEL,
                                    g_param_spec_string("additional-tab-label",
@@ -298,19 +296,19 @@ hildon_file_details_dialog_class_init(HildonFileDetailsDialogClass * klass)
                                    NULL, G_PARAM_READWRITE));
 
   g_object_class_install_property(gobject_class, PROP_MODEL,
-                 g_param_spec_object("model", "Model",
+                 g_param_spec_object("model", "Model", 
                  "HildonFileSystemModel to use when fetching information",
                  HILDON_TYPE_FILE_SYSTEM_MODEL, G_PARAM_READWRITE));
 
   /**
    * HildonFileDetailsDialog:enable_read_only_checkbox:
    *
-   * Whether or not to enable the read-only checkbox.
+   * Whether or not to enable the read-only checkbox. 
    */
   g_object_class_install_property(gobject_class,
                  PROP_ENABLE_READONLY_CHECKBOX,
                  g_param_spec_boolean("enable-read-only-checkbox",
-                 "Enable read-only checkbox",
+                 "Enable read-only checkbox", 
                  "Whether or not to enable the read-only checkbox.",
                  TRUE, G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
 
@@ -322,7 +320,7 @@ hildon_file_details_dialog_class_init(HildonFileDetailsDialogClass * klass)
   g_object_class_install_property(gobject_class,
                  PROP_SHOW_TYPE_ICON,
                  g_param_spec_boolean("show-type-icon",
-                 "Show file type icon",
+                 "Show file type icon", 
                  "Whether or not to show the file icon next to the file type.",
                  FALSE, G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
 }
@@ -350,31 +348,27 @@ hildon_file_details_dialog_init(HildonFileDetailsDialog *self)
     scroll = gtk_scrolled_window_new(NULL, NULL);
     vbox = gtk_vbox_new(FALSE, 0);
     group = gtk_size_group_new(GTK_SIZE_GROUP_BOTH);
-
+    
     priv->tab_label = gtk_label_new(_("sfil_ti_notebook_file"));
     g_object_ref(priv->tab_label);
-    g_object_ref_sink (GTK_OBJECT(priv->tab_label));
+    gtk_object_sink(GTK_OBJECT(priv->tab_label));
     gtk_widget_show(priv->tab_label);
 
     priv->file_device = g_object_new(GTK_TYPE_LABEL, "xalign", 0.0f, NULL);
     priv->file_location = g_object_new(GTK_TYPE_LABEL, "xalign", 0.0f, NULL);
-    gtk_label_set_ellipsize(GTK_LABEL(priv->file_location), 
-			    PANGO_ELLIPSIZE_NONE);
+    gtk_label_set_ellipsize(GTK_LABEL(priv->file_location), PANGO_ELLIPSIZE_END);
     priv->file_name = g_object_new(GTK_TYPE_LABEL, "xalign", 0.0f, NULL);
-    gtk_label_set_ellipsize(GTK_LABEL(priv->file_name), PANGO_ELLIPSIZE_NONE);
+    gtk_label_set_ellipsize(GTK_LABEL(priv->file_name), PANGO_ELLIPSIZE_END);
     priv->file_type = g_object_new(GTK_TYPE_LABEL, "xalign", 0.0f, NULL);
     priv->file_size = g_object_new(GTK_TYPE_LABEL, "xalign", 0.0f, NULL);
     priv->file_date = g_object_new(GTK_TYPE_LABEL,"xalign", 0.0f, NULL);
     priv->file_time = g_object_new(GTK_TYPE_LABEL, "xalign", 0.0f, NULL);
     priv->file_readonly = gtk_check_button_new();
 
-    gtk_label_set_line_wrap (GTK_LABEL (priv->file_name), TRUE);
-    gtk_label_set_line_wrap_mode (GTK_LABEL (priv->file_name), PANGO_WRAP_CHAR);
-
     hbox_type = gtk_hbox_new (FALSE, HILDON_MARGIN_DEFAULT);
     hbox_location = gtk_hbox_new(FALSE, HILDON_MARGIN_DEFAULT);
     hbox_device = gtk_hbox_new(FALSE, HILDON_MARGIN_DEFAULT);
-
+    
     priv->file_image = gtk_image_new ();
     priv->file_location_image = gtk_image_new();
     priv->file_device_image = gtk_image_new();
@@ -391,30 +385,30 @@ hildon_file_details_dialog_init(HildonFileDetailsDialog *self)
     gtk_box_pack_start(GTK_BOX(hbox_device), priv->file_device, TRUE, TRUE, 0);
 
     /* Create captions for the dialog */
-    caption_name = hildon_caption_new(group, _("ckdg_fi_properties_name_prompt"),
+    caption_name = hildon_caption_new(group, _("ckdg_fi_properties_name_prompt"), 
       priv->file_name, NULL, HILDON_CAPTION_OPTIONAL);
 #if 0
     caption_type = hildon_caption_new(group,
-                                      _("ckdg_fi_properties_type_prompt"),
-                                      priv->file_type, NULL, HILDON_CAPTION_OPTIONAL);
+				      _("ckdg_fi_properties_type_prompt"), 
+				      priv->file_type, NULL, HILDON_CAPTION_OPTIONAL);
 #else
     caption_type = hildon_caption_new(group,
-                                      _("ckdg_fi_properties_type_prompt"),
-                                      hbox_type, NULL, HILDON_CAPTION_OPTIONAL);
+				      _("ckdg_fi_properties_type_prompt"), 
+				      hbox_type, NULL, HILDON_CAPTION_OPTIONAL);
 #endif
     caption_location = hildon_caption_new(group,
-                               _("sfil_fi_properties_location_prompt"),
+                               _("sfil_fi_properties_location_prompt"), 
                                hbox_location, NULL, HILDON_CAPTION_OPTIONAL);
     caption_device = hildon_caption_new(group,
-                               _("sfil_fi_properties_device_prompt"),
+                               _("sfil_fi_properties_device_prompt"), 
       hbox_device, NULL, HILDON_CAPTION_OPTIONAL);
-    caption_date = hildon_caption_new(group, _("ckdg_fi_properties_date_prompt"),
+    caption_date = hildon_caption_new(group, _("ckdg_fi_properties_date_prompt"), 
       priv->file_date, NULL, HILDON_CAPTION_OPTIONAL);
-    caption_time = hildon_caption_new(group, _("ckdg_fi_properties_time_prompt"),
+    caption_time = hildon_caption_new(group, _("ckdg_fi_properties_time_prompt"), 
       priv->file_time, NULL, HILDON_CAPTION_OPTIONAL);
-    caption_size = hildon_caption_new(group, _("ckdg_fi_properties_size_prompt"),
+    caption_size = hildon_caption_new(group, _("ckdg_fi_properties_size_prompt"), 
       priv->file_size, NULL, HILDON_CAPTION_OPTIONAL);
-    caption_read = hildon_caption_new(group, _("ckdg_fi_properties_read_only"),
+    caption_read = hildon_caption_new(group, _("ckdg_fi_properties_read_only"), 
       priv->file_readonly, NULL, HILDON_CAPTION_OPTIONAL);
 
     hildon_caption_set_separator(HILDON_CAPTION(caption_name), "");
@@ -439,9 +433,9 @@ hildon_file_details_dialog_init(HildonFileDetailsDialog *self)
     gtk_box_pack_start(GTK_BOX(vbox), caption_read, FALSE, TRUE, 0);
 
     gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW(scroll), vbox);
-    gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scroll),
+    gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scroll), 
         GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
-    gtk_container_set_border_width(GTK_CONTAINER(scroll),
+    gtk_container_set_border_width(GTK_CONTAINER(scroll), 
         HILDON_MARGIN_DEFAULT);
     /* Both scrolled window and viewport have separate shadows... */
     gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(scroll),
@@ -450,12 +444,12 @@ hildon_file_details_dialog_init(HildonFileDetailsDialog *self)
         GTK_VIEWPORT(gtk_bin_get_child(GTK_BIN(scroll))),
         GTK_SHADOW_NONE);
 
-    gtk_container_set_focus_vadjustment(GTK_CONTAINER(vbox),
+    gtk_container_set_focus_vadjustment(GTK_CONTAINER(vbox), 
       gtk_scrolled_window_get_vadjustment(GTK_SCROLLED_WINDOW(scroll)));
 
     /* Populate dialog */
     gtk_notebook_append_page(priv->notebook, scroll,
-                             gtk_label_new(_("sfil_ti_notebook_common")));
+			     gtk_label_new(_("sfil_ti_notebook_common")));
 
     gtk_box_pack_start(GTK_BOX(GTK_DIALOG(self)->vbox),
                        GTK_WIDGET(priv->notebook), TRUE, TRUE, 0);
@@ -469,11 +463,11 @@ hildon_file_details_dialog_init(HildonFileDetailsDialog *self)
     geometry.max_height = 240 + (2 * HILDON_MARGIN_DEFAULT);
 
     gtk_window_set_geometry_hints(GTK_WINDOW(self),
-                                  GTK_WIDGET(priv->notebook), &geometry,
-                                  GDK_HINT_MIN_SIZE | GDK_HINT_MAX_SIZE);
+				  GTK_WIDGET(priv->notebook), &geometry,
+				  GDK_HINT_MIN_SIZE | GDK_HINT_MAX_SIZE);
 
     gtk_window_set_title (GTK_WINDOW (self), _("sfil_ti_file_details"));
-
+			  
     gtk_widget_show_all(GTK_WIDGET(priv->notebook));
 
     priv->ok_button = gtk_dialog_add_button(GTK_DIALOG(self),
@@ -483,11 +477,9 @@ hildon_file_details_dialog_init(HildonFileDetailsDialog *self)
                           _("sfil_bd_filetype_details_dialog_cancel"),
                           GTK_RESPONSE_CANCEL);
 
-    priv->toggle_handler = g_signal_connect(priv->file_readonly, "toggled",
-      G_CALLBACK(hildon_file_details_dialog_read_only_toggled),
+    priv->toggle_handler = g_signal_connect(priv->file_readonly, "toggled", 
+      G_CALLBACK(hildon_file_details_dialog_read_only_toggled), 
       self);
-    
-    gtk_widget_set_usize (GTK_WIDGET (self), 400, -1);
 }
 
 static void
@@ -503,7 +495,7 @@ hildon_file_details_dialog_set_property(GObject *object, guint param_id,
   notebook = priv->notebook;
   label = GTK_LABEL(priv->tab_label);
 
-  switch( param_id )
+  switch( param_id ) 
   {
     case PROP_SHOW_TABS:
     {
@@ -515,19 +507,19 @@ hildon_file_details_dialog_set_property(GObject *object, guint param_id,
     {
       GtkWidget *widget = g_value_get_object(value);
       GtkWidget *sw = gtk_scrolled_window_new(NULL, NULL);
-
+      
       if (gtk_notebook_get_n_pages(notebook) == 2)
         gtk_notebook_remove_page(notebook, 1);
 
       if (widget == NULL)
       {
-        widget = g_object_new(GTK_TYPE_LABEL,
+        widget = g_object_new(GTK_TYPE_LABEL, 
             "label", _("sfil_ia_filetype_no_details"), "yalign", 0.0f, NULL);
         gtk_widget_show(widget);
       }
 
       gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(sw),
-                                     GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
+				     GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
       gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW(sw), widget);
       gtk_viewport_set_shadow_type(GTK_VIEWPORT(GTK_BIN(sw)->child),
                                    GTK_SHADOW_NONE);
@@ -557,7 +549,7 @@ hildon_file_details_dialog_set_property(GObject *object, guint param_id,
           priv->delete_handler = g_signal_connect(priv->model, "row-deleted",
             G_CALLBACK(check_validity), object);
         }
-      }
+      }  
       break;
     }
     case PROP_ENABLE_READONLY_CHECKBOX:
@@ -569,9 +561,9 @@ hildon_file_details_dialog_set_property(GObject *object, guint param_id,
     case PROP_SHOW_TYPE_ICON:
     {
       if (g_value_get_boolean(value))
-        gtk_widget_show (priv->file_image);
+	gtk_widget_show (priv->file_image);
       else
-        gtk_widget_hide (priv->file_image);
+	gtk_widget_hide (priv->file_image);
       break;
     }
     default:
@@ -582,19 +574,19 @@ hildon_file_details_dialog_set_property(GObject *object, guint param_id,
 
 static void
 hildon_file_details_dialog_get_property( GObject *object, guint param_id,
-                                                           GValue *value, GParamSpec *pspec )
+			                                   GValue *value, GParamSpec *pspec )
 {
   HildonFileDetailsDialogPrivate *priv;
 
   priv = HILDON_FILE_DETAILS_DIALOG(object)->priv;
 
-  switch (param_id)
+  switch (param_id) 
   {
     case PROP_SHOW_TABS:
       g_value_set_boolean(value, gtk_notebook_get_show_tabs(priv->notebook));
       break;
     case PROP_ADDITIONAL_TAB:
-      g_assert(gtk_notebook_get_n_pages(priv->notebook) == 2);
+      g_assert(gtk_notebook_get_n_pages(priv->notebook) == 2);        
       g_value_set_object(value, gtk_notebook_get_nth_page(priv->notebook, 1));
       break;
     case PROP_ADDITIONAL_TAB_LABEL:
@@ -628,7 +620,7 @@ static void hildon_file_details_dialog_finalize(GObject * object)
     g_object_unref(priv->tab_label);
   if (priv->active_file)
     gtk_tree_row_reference_free(priv->active_file);
-
+    
   G_OBJECT_CLASS(file_details_dialog_parent_class)->finalize(object);
 }
 
@@ -641,7 +633,7 @@ static void hildon_file_details_dialog_finalize(GObject * object)
  * @parent: the parent window.
  * @filename: the filename.
  *
- * Creates a new #hildon_file_details_dialog AND new underlying
+ * Creates a new #hildon_file_details_dialog AND new underlying 
  * HildonFileSystemModel. Be carefull with #filename
  * parameter: You don't get any notification if something fails.
  * THIS FUNCTION IS DEPRICATED AND PROVIDED ONLY FOR
@@ -660,10 +652,10 @@ GtkWidget *hildon_file_details_dialog_new(GtkWindow * parent,
   model = g_object_new(HILDON_TYPE_FILE_SYSTEM_MODEL, NULL);
 
   dialog =
-        g_object_new(HILDON_TYPE_FILE_DETAILS_DIALOG,
+        g_object_new(HILDON_TYPE_FILE_DETAILS_DIALOG, 
           "has-separator", FALSE, "model", model, NULL);
 
-  if (filename && filename[0] &&
+  if (filename && filename[0] && 
     hildon_file_system_model_load_local_path(dialog->priv->model, filename, &iter))
       hildon_file_details_dialog_set_file_iter(dialog, &iter);
 
@@ -727,8 +719,6 @@ void hildon_file_details_dialog_set_file_iter(HildonFileDetailsDialog *self, Gtk
   /* Save iterator to priv struct as row reference */
   gtk_tree_row_reference_free(self->priv->active_file);
   path = gtk_tree_model_get_path(model, iter);
-  g_return_if_fail(path); // add some safety with logging here to clear up bug NB#51729, NB#52272, NB#52271
-
   self->priv->active_file = gtk_tree_row_reference_new(model, path);
   gtk_tree_path_free(path);
 
@@ -742,11 +732,7 @@ void hildon_file_details_dialog_set_file_iter(HildonFileDetailsDialog *self, Gtk
     -1);
 
   g_object_set(self->priv->file_name, "label", name, NULL);
-  if (mime && mime[0] != 0) {
-      g_object_set(self->priv->file_type, "label", _(mime), NULL);
-  } else {
-      g_warning("COLUMN_MIME_TYPE contains empty mime type for file: %s", name);
-  }
+  g_object_set(self->priv->file_type, "label", _(mime), NULL);
 
   if (size < 1024)
     g_snprintf(buffer, sizeof(buffer), _("ckdg_va_properties_size_kb"), 1);
@@ -770,30 +756,22 @@ void hildon_file_details_dialog_set_file_iter(HildonFileDetailsDialog *self, Gtk
 
   g_object_set(self->priv->file_size, "label", buffer, NULL);
 
-  if (time_stamp != 0)
-    {
-      /* Too bad. We cannot use GDate function, because it doesn't handle
-	 time, just dates */
-      time_val = (time_t) time_stamp;
-      time_struct = localtime(&time_val);
-      
-      /* There are no more logical names for these. We are allowed
-	 to hardcode */
-      strftime(buffer, sizeof(buffer), "%X", time_struct);
-      g_object_set(self->priv->file_time, "label", buffer, NULL);
-      
-      /* If format is passed directly to strftime, gcc complains about
-	 that some locales use only 2 digit year numbers. Using
-	 a temporary disable this warning (from strftime man page) */
-      fmt = "%x";
-      strftime(buffer, sizeof(buffer), fmt, time_struct);
-      g_object_set(self->priv->file_date, "label", buffer, NULL);
-    }
-  else
-    {
-      g_object_set(self->priv->file_time, "label", "-", NULL);
-      g_object_set(self->priv->file_date, "label", "-", NULL);
-    }
+  /* Too bad. We cannot use GDate function, because it doesn't handle
+      time, just dates */
+  time_val = (time_t) time_stamp;
+  time_struct = localtime(&time_val);
+
+  /* There are no more logical names for these. We are allowed
+      to hardcode */
+  strftime(buffer, sizeof(buffer), "%X", time_struct);
+  g_object_set(self->priv->file_time, "label", buffer, NULL);
+  
+  /* If format is passed directly to strftime, gcc complains about
+      that some locales use only 2 digit year numbers. Using
+      a temporary disable this warning (from strftime man page) */
+  fmt = "%x";
+  strftime(buffer, sizeof(buffer), fmt, time_struct);
+  g_object_set(self->priv->file_date, "label", buffer, NULL);
 
   {
     GdkPixbuf *icon;
@@ -804,12 +782,12 @@ void hildon_file_details_dialog_set_file_iter(HildonFileDetailsDialog *self, Gtk
        -1);
     if (icon)
       {
-        gtk_image_set_from_pixbuf (GTK_IMAGE (self->priv->file_image),
-                                   icon);
-        g_object_unref (icon);
+	gtk_image_set_from_pixbuf (GTK_IMAGE (self->priv->file_image),
+				   icon);
+	g_object_unref (icon);
       }
   }
-
+      
   /* Parent information */
   if (gtk_tree_model_iter_parent(model, &parent_iter, iter))
   {
@@ -819,13 +797,13 @@ void hildon_file_details_dialog_set_file_iter(HildonFileDetailsDialog *self, Gtk
     gtk_tree_model_get(model, &parent_iter,
       HILDON_FILE_SYSTEM_MODEL_COLUMN_DISPLAY_NAME, &location_name,
       HILDON_FILE_SYSTEM_MODEL_COLUMN_URI, &parent_path,
-      HILDON_FILE_SYSTEM_MODEL_COLUMN_ICON, &location_icon, -1);
+      HILDON_FILE_SYSTEM_MODEL_COLUMN_ICON, &location_icon, -1);      
 
     if (parent_path)
       location_readonly = !write_access(parent_path);
 
     gtk_label_set_text(GTK_LABEL(self->priv->file_location), location_name);
-    gtk_image_set_from_pixbuf(GTK_IMAGE(self->priv->file_location_image),
+    gtk_image_set_from_pixbuf(GTK_IMAGE(self->priv->file_location_image), 
       location_icon);
 
     if (G_IS_OBJECT(location_icon))
@@ -843,17 +821,17 @@ void hildon_file_details_dialog_set_file_iter(HildonFileDetailsDialog *self, Gtk
 
       if (gtk_tree_model_iter_parent(model, &temp_iter, &parent_iter))
         parent_iter = temp_iter;
-      else
+      else 
         break;
-    }
+    }   
 
     gtk_tree_model_get(model, &parent_iter,
-      HILDON_FILE_SYSTEM_MODEL_COLUMN_DISPLAY_NAME, &location_name,
-      HILDON_FILE_SYSTEM_MODEL_COLUMN_ICON, &location_icon,
+      HILDON_FILE_SYSTEM_MODEL_COLUMN_DISPLAY_NAME, &location_name, 
+      HILDON_FILE_SYSTEM_MODEL_COLUMN_ICON, &location_icon, 
       -1);
 
     gtk_label_set_text(GTK_LABEL(self->priv->file_device), location_name);
-    gtk_image_set_from_pixbuf(GTK_IMAGE(self->priv->file_device_image),
+    gtk_image_set_from_pixbuf(GTK_IMAGE(self->priv->file_device_image), 
       location_icon);
 
     if (G_IS_OBJECT(location_icon))
@@ -861,7 +839,7 @@ void hildon_file_details_dialog_set_file_iter(HildonFileDetailsDialog *self, Gtk
     g_free(location_name);
     g_free(parent_path);
   }
-  else
+  else 
   {   /* We really should not come here */
       gtk_label_set_text(GTK_LABEL(self->priv->file_location), "");
       gtk_image_set_from_pixbuf(GTK_IMAGE(self->priv->file_location_image), NULL);
@@ -872,7 +850,7 @@ void hildon_file_details_dialog_set_file_iter(HildonFileDetailsDialog *self, Gtk
   /* We do not want initial setting to cause any action */
   g_signal_handler_block(self->priv->file_readonly, self->priv->toggle_handler);
 
-  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(self->priv->file_readonly),
+  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(self->priv->file_readonly), 
     location_readonly || !write_access(uri));
   gtk_widget_set_sensitive(self->priv->file_readonly, !location_readonly);
 
@@ -895,7 +873,7 @@ void hildon_file_details_dialog_set_file_iter(HildonFileDetailsDialog *self, Gtk
  *
  * Returns: %TRUE, if dialog is displaying some information.
  */
-gboolean
+gboolean 
 hildon_file_details_dialog_get_file_iter(HildonFileDetailsDialog *self, GtkTreeIter *iter)
 {
   GtkTreePath *path;
@@ -908,9 +886,9 @@ hildon_file_details_dialog_get_file_iter(HildonFileDetailsDialog *self, GtkTreeI
   path = gtk_tree_row_reference_get_path(self->priv->active_file);
   if (!path)
     return FALSE;
-
+  
   result = gtk_tree_model_get_iter(GTK_TREE_MODEL(self->priv->model), iter, path);
-  gtk_tree_path_free(path);
+  gtk_tree_path_free(path);  
 
   return result;
 }
